const inquirer = require('inquirer');
const { isEmpty, isNil } = require('lodash/fp');

const requireValue = (name) => (value) => {
    return isEmpty(value) ? `You must provide a valid ${name}!` : true;
};

const _questionToTypeReducer = (a, q) => {
    a[q.name] = q.default;
    return a;
};

const prompt = async (questions, { skipDefaultQuestions = false } = {}) => {
    if (skipDefaultQuestions) {
        const questionsWithoutDefaults = questions.filter((x) => isNil(x.default));
        if (isEmpty(questionsWithoutDefaults)) {
            return questions.reduce(_questionToTypeReducer, {});
        } else {
            const res = await inquirer.prompt(questionsWithoutDefaults);
            const defaultAnswers = questions
                .filter((x) => !isNil(x.default))
                .reduce(_questionToTypeReducer, {});
            return Object.assign({}, res, defaultAnswers);
        }
    }
    return inquirer.prompt(questions);
};

module.exports = {
    prompt,
    requireValue,
};
